@@ -45,12 +45,15 @@ A few more commands (cat, create, update, associate)
 
 import argparse
 import os
+import collections
 import shutil
 import sys
 import synapseclient
 from synapseclient import Activity
 import utils
 import signal
+from StringIO import StringIO
+import traceback
 import json
 import warnings
 from synapseclient.exceptions import *
@@ -68,8 +71,7 @@ def query(args, syn):
         pass
     ## TODO: Should use loop over multiple returned values if return is too long
     results = syn.chunkedQuery(' '.join(args.queryString))
-
-    headings = {}
+    headings = collections.OrderedDict()
     temp = [] # Since query returns a generator, the results must be stored locally
     for res in results:
         temp.append(res)
@@ -78,7 +80,6 @@ def query(args, syn):
     if len(headings) == 0: # No results found
         return 
     sys.stdout.write('%s\n' %'\t'.join(headings))
-    
     for res in temp:
         out = []
         for key in headings:
@@ -124,7 +125,7 @@ def store(args, syn):
                   'path': args.file}
     #Overide setting for parameters included in args
     entity['name'] =  args.name if args.name is not None else entity['name']
-    entity['description'] = args.description if args.description is not None else entity['description']
+    entity['description'] = args.description if args.description is not None else entity.get('description', None)
     entity['parentId'] = args.parentid if args.parentid is not None else entity['parentId']
     entity['path'] = args.file if args.file is not None else None
     if utils.is_url(args.file):
@@ -307,19 +308,14 @@ def submit(args, syn):
         if not os.path.exists(args.file):
             raise IOError('file path %s not valid \n' % args.file)
         # //ideally this should be factored out
-        try:
-            synFile = syn.store(synapseclient.File(path=args.file,parent=args.parentId),
-                                used=_convertProvenanceList(args.used, args.limitSearch, syn),
-                                executed=_convertProvenanceList(args.executed, args.limitSearch, syn))
-            args.entity = synFile.id
-        except Exception as e:
-            raise SynapseError('Unable to upload file %s to synapse \n' % args.file)
-    try:    
-        submission = syn.submit(args.evaluationID, args.entity, name=args.name, teamName=args.teamName)
-        sys.stdout.write('Submitted (id: %s) entity: %s\t%s to Evaluation: %s\n' \
-            % (submission['id'], submission['entityId'], submission['name'], submission['evaluationId']))
-    except Exception as e:
-        raise SynapseError('Unable to successfully submit to the evaluation %s \n' % args.evaluationID)
+        synFile = syn.store(synapseclient.File(path=args.file,parent=args.parentId),
+                            used=_convertProvenanceList(args.used, args.limitSearch, syn),
+                            executed=_convertProvenanceList(args.executed, args.limitSearch, syn))
+        args.entity = synFile.id
+
+    submission = syn.submit(args.evaluationID, args.entity, name=args.name, teamName=args.teamName)
+    sys.stdout.write('Submitted (id: %s) entity: %s\t%s to Evaluation: %s\n' \
+        % (submission['id'], submission['entityId'], submission['name'], submission['evaluationId']))
         
         
 def login(args, syn):
