@@ -356,7 +356,7 @@ class Entity(collections.MutableMapping):
                     f.write('  ')
                     f.write(key)
                     f.write('=')
-                    f.write(str(dictionary[key]))
+                    f.write(unicode(dictionary[key]).encode('utf-8'))
                     f.write('\n')
 
         write_kvps(self.__dict__, lambda key: not (key in ['properties', 'annotations'] or key.startswith('__')))
@@ -440,6 +440,7 @@ class File(Entity, Versionable):
     :param parent:       Project or Folder where this File is stored
     :param synapseStore: Whether the File should be uploaded or if only the path should be stored.
                          Defaults to True (file should be uploaded)
+    :param contentType:  Manually specify Content-type header, for example "application/png" or "application/json; charset=UTF-8"
 
     ::
     
@@ -615,6 +616,7 @@ def is_locationable(entity):
     else:
         raise SynapseMalformedEntityError('Can\'t determine if %s is Locationable' % str(entity))
 
+
 def is_container(entity):
     """Test if an entity is a container (ie, a Project or a Folder)"""
     if 'concreteType' in entity:
